Module utils

Module utils 

utilties supporting various mathematical routines for machine learning tasks.

Modules

arith

Functions

floor_div
round_to
Round the given value to the given number of decimal places.